==> owncloud-8.2.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/nl.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Activiteit",
    "Personal activity feed for %s" : "Persoonlijk activiteitenkanaal voor %s",
    "Your feed URL is invalid" : "Uw feed URL is ongeldig",
    "Your settings have been updated." : "Uw instellingen zijn bijgewerkt",
    "Mail" : "E-mail",
    "Stream" : "Doorlopend",
    "Activities" : "Activiteiten",
    "Error loading activities" : "Fout bij laden activiteiten",
    "No activities" : "Geen activiteiten",
    "This stream will show events like additions, changes & shares" : "Deze stream laat gebeurtenissen als toevoegingen, veranderingen en gedeelde bestanden zien",
    "There are no events for this filter" : "Er zijn geen afspraken voor dit filter",
    "Activity notification" : "Activiteitenmelding",
    "All Activities" : "Alle activiteiten",
    "Activities by you" : "Activiteiten van uzelf",
    "Activities by others" : "Activiteiten van anderen",
    "\"remote user\"" : "\"externe gebruiker\"",
    "in %s" : "in %s",
    "%s and %s" : "%s en %s",
    ", " : ", ",
    "_%s and <strong %s>%n more</strong>_::_%s and <strong %s>%n more</strong>_" : ["%s en <strong %s>%n meer</strong>","%s en <strong %s>%n meer</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s en nog %n","%s en nog %n"],
    "Hello %s," : "Hallo %s,",
    "You are receiving this email because the following things happened at %s" : "U ontvangt deze e-mail omdat het volgende plaatsvond op %s.",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* en %n meer","* en %n meer"],
    "Notifications" : "Meldingen",
    "List your own actions in the stream" : "Toon uw eigen acties in het overzicht",
    "Notify about your own actions via email" : "Melding van uw eigen acties via e-mail",
    "You need to set up your email address before you can receive notification emails." : "U moet uw e-mailadres instellen voordat u meldingen kunt ontvangen.",
    "Send emails:" : "Verstuur e-mails:",
    "Hourly" : "Per uur",
    "Daily" : "Dagelijks",
    "Weekly" : "Wekelijks",
    "Activity feed" : "Activiteitenkanaal",
    "Enable RSS feed" : "Aanzetten RSS kanaal",
    "No activity yet" : "Nog geen activiteit",
    "No more events to load" : "Geen activiteiten meer om te laden ",
    "Files" : "Bestanden",
    "_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_" : ["%s en <strong class=\"has-tooltip\" title=\"%s\">%n meer</strong>","%s en <strong class=\"has-tooltip\" title=\"%s\">%n meer</strong>"]
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/nl.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Activiteit",
    "Personal activity feed for %s" : "Persoonlijk activiteitenkanaal voor %s",
    "Your feed URL is invalid" : "Uw feed URL is ongeldig",
    "Your settings have been updated." : "Uw instellingen zijn bijgewerkt",
    "Mail" : "E-mail",
    "Stream" : "Doorlopend",
    "Activities" : "Activiteiten",
    "Error loading activities" : "Fout bij laden activiteiten",
    "No activities" : "Geen activiteiten",
    ", " : ", ",
    "{parameterList} and {lastParameter}" : "{parameterList} en {lastParameter}",
    "_{parameterList} and {linkStart}%n more{linkEnd}_::_{parameterList} and {linkStart}%n more{linkEnd}_" : ["{parameterList} en {linkStart}%n meer{linkEnd}","{parameterList} en {linkStart}%n meer{linkEnd}"],
    "in {directory}" : "in {directory}",
    "This stream will show events like additions, changes & shares" : "Deze stream laat gebeurtenissen als toevoegingen, veranderingen en gedeelde bestanden zien",
    "There are no events for this filter" : "Er zijn geen afspraken voor dit filter",
    "Today" : "Vandaag",
    "Yesterday" : "Gisteren",
    "\"remote user\"" : "\"externe gebruiker\"",
    "Activity notification" : "Activiteitenmelding",
    "All Activities" : "Alle activiteiten",
    "Activities by you" : "Activiteiten van uzelf",
    "Activities by others" : "Activiteiten van anderen",
    "%s and %s" : "%s en %s",
    "Hello %s," : "Hallo %s,",
    "You are receiving this email because the following things happened at %s" : "U ontvangt deze e-mail omdat het volgende plaatsvond op %s.",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* en %n meer","* en %n meer"],
    "List your own actions in the stream" : "Toon uw eigen acties in het overzicht",
    "Notify about your own actions via email" : "Melding van uw eigen acties via e-mail",
    "You need to set up your email address before you can receive notification emails." : "U moet uw e-mailadres instellen voordat u meldingen kunt ontvangen.",
    "Send emails:" : "Verstuur e-mails:",
    "Hourly" : "Per uur",
    "Daily" : "Dagelijks",
    "Weekly" : "Wekelijks",
    "Activity feed" : "Activiteitenkanaal",
    "Enable RSS feed" : "Aanzetten RSS kanaal",
    "No activity yet" : "Nog geen activiteit",
    "No more events to load" : "Geen activiteiten meer om te laden ",
    "Files" : "Bestanden"
},
"nplurals=2; plural=(n != 1);");
